﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using System.Windows.Controls;

using DomainModel;

using IdeaBlade.EntityModel;
using IdeaBlade.EntityModel.Security;

namespace PocoApp {

  public partial class MainPage : UserControl {
    public MainPage() {
      InitializeComponent();
      CreateEntityManager();
      Login();
    }

    private async void Login() {
      var cred = new LoginCredential("demo1", "demo2", "demo3");

      WriteMessage("Logging in ...");

      try {
        var ac = await Authenticator.Instance.LoginAsync(cred);
        Authenticator.Instance.DefaultAuthenticationContext = ac;
        WriteMessage("Logged in");
        LoadData();
      } catch (Exception e) {
        WriteMessage(e.Message);
      }
    }

    private void CreateEntityManager() {
      _mgr = new EntityManager();
    }

    #region LoadData

    private async void LoadData() {
      try {
        var results = await _mgr.ExecuteQueryAsync<State>(_mgr.States().Where(s => s.Lower49));
        _states.Clear();
        foreach (State aState in results) {
          _states.Add(aState);
        }
        _statesDataGrid.ItemsSource = _states;
        ReportFetchCount(results);
      } catch (Exception e) {
        WriteMessage(e.Message);
      }
    }

    #endregion LoadData

    private void ReportFetchCount(IEnumerable results) {
      if (results == null) {
        WriteMessage("Fetch failed");
      } else {
        WriteMessage(string.Format("Retrieved {0} items.", results.Cast<Object>().Count()));
      }
    }

    public void WriteMessage(string msg) {
      _statusTextBlock.Text += Environment.NewLine + msg;
    }

    #region Private Fields
    EntityManager _mgr;
    List<State> _states = new List<State>();
    #endregion Private Fields
  }
}
